@@ -12,11 +12,11 @@ Data::Pareto - Computing Pareto sets in Perl
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ rather a bag than a set, but is useful in practice (e.g. when we want to
 preserve two solutions giving the same objectives value, but structurally
 different). This assumption influences dominance definition given above:
 two duplicates never dominate each other and hence can be present in the Pareto
-set. This is controlled by C<duplicates> option passed to L<new()|new>: if set
+set. This is controlled by C<duplicates> option passed to L<new()|/new>: if set
 to C<true> value, duplicates are allowed in Pareto set; otherwise, only the
 first found element of the subset of duplicated vectors is preserved in Pareto
 set.
@@ -63,7 +63,7 @@ definition of domination less clear.
 
 By default, the comparison of column values is numerical and the smaller
 value dominates the larger one. If you want to override this behaviour, pass
-your own dominator sub in arguments to L<new()|new>.
+your own dominator sub in arguments to L<new()|/new>.
 
 =head1 FUNCTIONS
 
@@ -168,7 +168,7 @@ given column:
 
 =back
 
-The rest of arguments are assumed to be vectors, and passed to L<add()|add>
+The rest of arguments are assumed to be vectors, and passed to L<add()|/add>
 method.
 
 =cut
@@ -280,7 +280,7 @@ sub _update_pareto {
 
 Checks if the first vector passed is dominated by the second one.
 The comparison is made based on the values in vectors' columns, which
-were passed to L<new()|new>.
+were passed to L<new()|/new>.
 
 The vectors passed are never duplicates of each other when this method is
 called from inside this module.
@@ -413,7 +413,7 @@ of techniques which might be applied to improve the performance:
 =over
 
 =item * defer the phase of removing vectors dominated by newly added vectors
-to L<get_pareto()|get_pareto> call; this results in smaller number of arrays
+to L<get_pareto()|/get_pareto> call; this results in smaller number of arrays
 rewritings.
 
 =item * split the set of vectors being added into smaller subsets, calculate
@@ -464,10 +464,12 @@ L<http://search.cpan.org/dist/Data-Pareto>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Przemyslaw Wesolek, all rights reserved.
+
+Copyright 2009 Przemyslaw Wesolek
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+under the terms of the Artistic License 2.0. For details, see the full
+text of the license in the file LICENSE.
 
 =cut
 
